@@ -1,11 +1,11 @@
 # coding=utf-8
 # Author: SafetyCulture
 # Copyright: © SafetyCulture 2016
-import time
 import sys
-import pandas as pd
-import numpy as np
+import time
 
+import numpy as np
+import pandas as pd
 from rich import print
 from tqdm import tqdm
 
@@ -148,7 +148,7 @@ def sync_exports(logger, settings, sc_client):
         # back to square one. From testing, 500 is a good number to use here and I do not recommend
         # going higher.
 
-        per_chunk = settings['chunks']
+        per_chunk = settings["chunks"]
 
         if "sql" in settings[EXPORT_FORMATS]:
             get_started = sql_setup(logger, settings, "audit")
@@ -192,13 +192,9 @@ def loop_through_chunks(
 
     for chunk in chunks_to_process:
         if per_chunk > export_total:
-            logger.info(
-                f"Downloading {str(export_total)} total inspections..."
-            )
+            logger.info(f"Downloading {str(export_total)} total inspections...")
         else:
-            logger.info(
-                f"Downloading inspection data..."
-            )
+            logger.info(f"Downloading inspection data...")
         audits_to_process = sc_client.raise_pool(chunk)
         all_audits = []
         audit_pbar = tqdm(
@@ -218,15 +214,13 @@ def loop_through_chunks(
                     + str(export_total)
                     + ")"
                 )
-                process_audit(
+                debug_code, modified_at = process_audit(
                     logger,
                     settings,
                     sc_client,
                     audit,
                     get_started,
-                    all_audits=all_audits,
-                    debug_code=None,
-                    modified_at=None
+                    all_audits=all_audits
                 )
                 export_count += 1
         if "sql" in settings[EXPORT_FORMATS]:
@@ -236,10 +230,19 @@ def loop_through_chunks(
             update_sync_marker_file(modified_at, settings[CONFIG_NAME])
 
 
-def process_audit(logger, settings, sc_client, audit, get_started, all_audits=[], debug_code=None, modified_at=None):
+def process_audit(
+    logger,
+    settings,
+    sc_client,
+    audit,
+    get_started,
+    all_audits=[]
+):
     """
     Export audit in the format specified in settings. Formats include PDF, JSON, CSV, MS Word (docx), media, or
     web report link.
+    :param get_started:
+    :param all_audits:
     :param logger:      The logger
     :param settings:    Settings from command line and configuration file
     :param sc_client:   instance of safetypy.SafetyCulture class
@@ -295,12 +298,6 @@ def process_audit(logger, settings, sc_client, audit, get_started, all_audits=[]
     modified_at = audit["modified_at"]
 
     return debug_code, modified_at
-    # else:
-    #     debug_code = ""
-    #     modified_at = ""
-    #     return debug_code, modified_at
-    # logger.debug("setting last modified to " + audit["modified_at"])
-    # update_sync_marker_file(audit["modified_at"], settings[CONFIG_NAME])
 
 
 def db_formatter(settings, audit_json, all_audits=[]):
