@@ -1,11 +1,11 @@
-import sqlalchemy
-import unicodecsv as csv
-import json
-import sys
-import os
 import copy
+import json
+import os
+import sys
 from datetime import datetime
 
+import unicodecsv as csv
+
 CSV_HEADER_ROW = [
     "SortingIndex",
     "ItemType",
@@ -280,7 +280,7 @@ class CsvExporter:
         """
         audit_data_property = self.audit_json["audit_data"]
         template_data_property = self.audit_json["template_data"]
-        if 'date_completed' in audit_data_property:
+        if "date_completed" in audit_data_property:
             audit_date_completed = audit_data_property["date_completed"]
         else:
             audit_date_completed = None
@@ -571,10 +571,10 @@ class CsvExporter:
         :param item:    single item in JSON format
         :return:        score percentage property or empty string if property does not exist
         """
-        if isinstance(get_json_property(item, "scoring", SCORE_PERCENTAGE), float):
+        if isinstance(get_json_property(item, "scoring", SCORE_PERCENTAGE), (float, int)):
             return get_json_property(item, "scoring", SCORE_PERCENTAGE)
         elif isinstance(
-            get_json_property(item, "scoring", COMBINED_SCORE_PERCENTAGE), float
+            get_json_property(item, "scoring", COMBINED_SCORE_PERCENTAGE), (float, int)
         ):
             return get_json_property(item, "scoring", COMBINED_SCORE_PERCENTAGE)
         else:
