@@ -1,12 +1,11 @@
 import datetime
 
-import pandas as pd
 import numpy as np
-
+import pandas as pd
 from sqlalchemy import *
 from sqlalchemy.exc import IntegrityError, OperationalError
-from sqlalchemy.orm import sessionmaker
 from sqlalchemy.ext.declarative import declarative_base
+from sqlalchemy.orm import sessionmaker
 
 import iauditor_exporter.modules.csvExporter as csvExporter
 from iauditor_exporter.modules.actions import transform_action_object_to_list
@@ -17,26 +16,42 @@ from iauditor_exporter.modules.model import *
 def test_sql_settings(logger, settings):
     Base = declarative_base()
     Base.metadata.clear()
-    connection_string = "{}://{}:{}@{}:{}/{}".format(
-        settings['export_options']["database_type"],
-        settings['export_options']["database_user"],
-        settings['export_options']["database_pwd"],
-        settings['export_options']["database_server"],
-        settings['export_options']["database_port"],
-        settings['export_options']["database_name"],
-    )
+    if "export_options" in settings:
+        for k, v in settings["export_options"].items():
+            if k in [
+                "database_type",
+                "database_user",
+                "database_pwd",
+                "database_server",
+                "database_port",
+                "database_name",
+            ]:
+                if v is None:
+                    logger.warning(
+                        f"All fields must be filled out to test your database settings. At least {k} is empty."
+                    )
+                    return False
 
-    engine = create_engine(connection_string, pool_pre_ping=True)
-    logger.info("Attempting to connect to database...")
-    try:
-        conn = engine.connect()
-        results = conn.execute("SELECT 1")
-        logger.info("Connected successfully.")
-        conn.close()
-        return True
-    except:
-        logger.warning("Unable to connect to database")
-        return False
+        connection_string = "{}://{}:{}@{}:{}/{}".format(
+            settings["export_options"]["database_type"],
+            settings["export_options"]["database_user"],
+            settings["export_options"]["database_pwd"],
+            settings["export_options"]["database_server"],
+            settings["export_options"]["database_port"],
+            settings["export_options"]["database_name"],
+        )
+
+        engine = create_engine(connection_string, pool_pre_ping=True)
+        logger.info("Attempting to connect to database...")
+        try:
+            conn = engine.connect()
+            results = conn.execute("SELECT 1")
+            logger.info("Connected successfully.")
+            conn.close()
+            return True
+        except Exception as ex:
+            logger.warning(f"Unable to connect to database: {ex}")
+            return False
 
 
 def sql_setup(logger, settings, action_or_audit):
@@ -58,15 +73,14 @@ def sql_setup(logger, settings, action_or_audit):
             table = settings[SQL_TABLE]
         else:
             table = "iauditor_data"
-        Database = set_table(table, merge, Base)
+        Database = set_table(table, merge, Base, user_schema=settings[DB_SCHEMA])
     elif action_or_audit == "actions":
         if settings[ACTIONS_TABLE] is not None:
             table = settings[ACTIONS_TABLE]
         else:
             table = "iauditor_actions_data"
-        Database = set_actions_table(table, actions_merge, Base)
+        Database = set_actions_table(table, actions_merge, Base, user_schema=settings[DB_SCHEMA])
     else:
-        print("No Match")
         sys.exit()
 
     if HEROKU_URL in settings:
@@ -103,8 +117,7 @@ def sql_setup(logger, settings, action_or_audit):
         else:
             validation = input(
                 "It doesn't look like a table called {} exists on your server. Would you like the "
-                "script to try and create the table for you now? (If you're using "
-                "docker, you need to set APPROVE_TABLE_CREATION to true in your config file) "
+                "script to try and create the table for you now?"
                 "(y/n)  ".format(db_setting)
             )
             validation = validation.lower()
@@ -216,7 +229,7 @@ def bulk_import_sql(logger, df_dict, get_started):
     for audit in df_dict:
         try:
             logger.info(f"Inserting {audit[0]['AuditID']} into the database")
-            session.bulk_insert_mappings(database, audit)
+            session.bulk_insert_mappings(database, audit, render_nulls=True)
         except KeyboardInterrupt:
             logger.warning("Interrupted by user, exiting.")
             session.rollback()
@@ -238,9 +251,7 @@ def bulk_import_sql(logger, df_dict, get_started):
         #     else:
         #         session.add(row_to_dict)
         except IntegrityError:
-            logger.info(
-                "Duplicate inspection found, updating instead."
-            )
+            logger.info("Duplicate inspection found, updating instead.")
             session.rollback()
             session.bulk_update_mappings(database, audit)
         except Exception as ex:
@@ -278,16 +289,10 @@ def save_exported_actions_to_db(logger, actions_array, settings, get_started):
     actions_db = get_started[2]
     session = get_started[1]
 
-    # engine = get_started[1]
-    # actions_db = get_started[4]
-
     if not actions_array:
-        # logger.info('No actions returned after ' + get_last_successful_actions_export(logger, settings[CONFIG_NAME]))
         logger.info("No actions returned.")
         return
     logger.info("Exporting " + str(len(actions_array)) + " actions")
-    # Session = sessionmaker(bind=engine)
-    # session = Session()
     bulk_actions = []
     for action in actions_array:
         action_as_list = transform_action_object_to_list(action)
@@ -308,7 +313,7 @@ def save_exported_actions_to_db(logger, actions_array, settings, get_started):
     df_dict = df.to_dict(orient="records")
 
     try:
-        session.bulk_insert_mappings(actions_db, df_dict)
+        session.bulk_insert_mappings(actions_db, df_dict, render_nulls=True)
     except KeyboardInterrupt:
         logger.warning("Interrupted by user, exiting.")
         session.rollback()
